[libhandy/swipe-tracker-public: 5/16] swipeable: Rename begin_swipe() to start_swipe()



commit 343f29d0c08945b3c358107ce487d81a8d6ae61e
Author: Alexander Mikhaylenko <alexm gnome org>
Date:   Sun Jun 14 22:51:09 2020 +0500

    swipeable: Rename begin_swipe() to start_swipe()
    
    Also rename the associated function and signal. This will allow to have a
    less awkward name for the signal later.
    
    Signed-off-by: Alexander Mikhaylenko<alexm gnome org>

 debian/libhandy-1-0.symbols     |  4 ++--
 src/hdy-carousel.c              |  4 ++--
 src/hdy-deck.c                  |  6 +++---
 src/hdy-leaflet.c               |  6 +++---
 src/hdy-stackable-box-private.h |  2 +-
 src/hdy-stackable-box.c         |  2 +-
 src/hdy-swipe-group.c           |  6 +++---
 src/hdy-swipe-tracker.c         |  2 +-
 src/hdy-swipeable-private.h     |  2 +-
 src/hdy-swipeable.c             | 18 +++++++++---------
 src/hdy-swipeable.h             |  4 ++--
 11 files changed, 28 insertions(+), 28 deletions(-)
---
diff --git a/debian/libhandy-1-0.symbols b/debian/libhandy-1-0.symbols
index f41f7989..a3bdd782 100644
--- a/debian/libhandy-1-0.symbols
+++ b/debian/libhandy-1-0.symbols
@@ -270,7 +270,7 @@ libhandy-1.so.0 libhandy-1-0 #MINVER#
  hdy_squeezer_set_transition_type@LIBHANDY_1_0 0.0.10
  hdy_squeezer_transition_type_get_type@LIBHANDY_1_0 0.0.10
  hdy_stackable_box_add@LIBHANDY_1_0 0.80.0
- hdy_stackable_box_begin_swipe@LIBHANDY_1_0 0.80.0
+ hdy_stackable_box_start_swipe@LIBHANDY_1_0 0.80.0
  hdy_stackable_box_direction_changed@LIBHANDY_1_0 0.80.0
  hdy_stackable_box_draw@LIBHANDY_1_0 0.80.0
  hdy_stackable_box_end_swipe@LIBHANDY_1_0 0.80.0
@@ -335,7 +335,7 @@ libhandy-1.so.0 libhandy-1-0 #MINVER#
  hdy_swipe_tracker_set_enabled@LIBHANDY_1_0 0.0.11
  hdy_swipe_tracker_set_reversed@LIBHANDY_1_0 0.0.11
  hdy_swipe_tracker_shift_position@LIBHANDY_1_0 0.81.0
- hdy_swipeable_begin_swipe@LIBHANDY_1_0 0.0.12
+ hdy_swipeable_start_swipe@LIBHANDY_1_0 0.0.12
  hdy_swipeable_emit_switch_child@LIBHANDY_1_0 0.0.12
  hdy_swipeable_end_swipe@LIBHANDY_1_0 0.0.12
  hdy_swipeable_get_cancel_progress@LIBHANDY_1_0 0.81.0
diff --git a/src/hdy-carousel.c b/src/hdy-carousel.c
index 4a72e50f..a8c607b9 100644
--- a/src/hdy-carousel.c
+++ b/src/hdy-carousel.c
@@ -180,7 +180,7 @@ hdy_carousel_switch_child (HdySwipeable *swipeable,
 }
 
 static void
-hdy_carousel_begin_swipe (HdySwipeable           *swipeable,
+hdy_carousel_start_swipe (HdySwipeable           *swipeable,
                           HdyNavigationDirection  direction,
                           gboolean                direct)
 {
@@ -917,7 +917,7 @@ static void
 hdy_carousel_swipeable_init (HdySwipeableInterface *iface)
 {
   iface->switch_child = hdy_carousel_switch_child;
-  iface->begin_swipe = hdy_carousel_begin_swipe;
+  iface->start_swipe = hdy_carousel_start_swipe;
   iface->update_swipe = hdy_carousel_update_swipe;
   iface->end_swipe = hdy_carousel_end_swipe;
   iface->get_distance = hdy_carousel_get_distance;
diff --git a/src/hdy-deck.c b/src/hdy-deck.c
index 024bb226..9dc62445 100644
--- a/src/hdy-deck.c
+++ b/src/hdy-deck.c
@@ -778,11 +778,11 @@ hdy_deck_switch_child (HdySwipeable *swipeable,
 }
 
 static void
-hdy_deck_begin_swipe (HdySwipeable           *swipeable,
+hdy_deck_start_swipe (HdySwipeable           *swipeable,
                       HdyNavigationDirection  direction,
                       gboolean                direct)
 {
-  hdy_stackable_box_begin_swipe (HDY_GET_HELPER (swipeable), direction, direct);
+  hdy_stackable_box_start_swipe (HDY_GET_HELPER (swipeable), direction, direct);
 }
 
 static void
@@ -1077,7 +1077,7 @@ static void
 hdy_deck_swipeable_init (HdySwipeableInterface *iface)
 {
   iface->switch_child = hdy_deck_switch_child;
-  iface->begin_swipe = hdy_deck_begin_swipe;
+  iface->start_swipe = hdy_deck_start_swipe;
   iface->update_swipe = hdy_deck_update_swipe;
   iface->end_swipe = hdy_deck_end_swipe;
   iface->get_distance = hdy_deck_get_distance;
diff --git a/src/hdy-leaflet.c b/src/hdy-leaflet.c
index 8d658f90..6041dbdf 100644
--- a/src/hdy-leaflet.c
+++ b/src/hdy-leaflet.c
@@ -851,11 +851,11 @@ hdy_leaflet_switch_child (HdySwipeable *swipeable,
 }
 
 static void
-hdy_leaflet_begin_swipe (HdySwipeable           *swipeable,
+hdy_leaflet_start_swipe (HdySwipeable           *swipeable,
                          HdyNavigationDirection  direction,
                          gboolean                direct)
 {
-  hdy_stackable_box_begin_swipe (HDY_GET_HELPER (swipeable), direction, direct);
+  hdy_stackable_box_start_swipe (HDY_GET_HELPER (swipeable), direction, direct);
 }
 
 static void
@@ -1182,7 +1182,7 @@ static void
 hdy_leaflet_swipeable_init (HdySwipeableInterface *iface)
 {
   iface->switch_child = hdy_leaflet_switch_child;
-  iface->begin_swipe = hdy_leaflet_begin_swipe;
+  iface->start_swipe = hdy_leaflet_start_swipe;
   iface->update_swipe = hdy_leaflet_update_swipe;
   iface->end_swipe = hdy_leaflet_end_swipe;
   iface->get_distance = hdy_leaflet_get_distance;
diff --git a/src/hdy-stackable-box-private.h b/src/hdy-stackable-box-private.h
index 2c9674d3..01296eb4 100644
--- a/src/hdy-stackable-box-private.h
+++ b/src/hdy-stackable-box-private.h
@@ -88,7 +88,7 @@ void             hdy_stackable_box_set_child_allow_visible (HdyStackableBox *sel
 void             hdy_stackable_box_switch_child (HdyStackableBox *self,
                                                  guint            index,
                                                  gint64           duration);
-void             hdy_stackable_box_begin_swipe (HdyStackableBox        *self,
+void             hdy_stackable_box_start_swipe (HdyStackableBox        *self,
                                                 HdyNavigationDirection  direction,
                                                 gboolean                direct);
 void             hdy_stackable_box_update_swipe (HdyStackableBox *self,
diff --git a/src/hdy-stackable-box.c b/src/hdy-stackable-box.c
index 579c36c7..f93ebdf3 100644
--- a/src/hdy-stackable-box.c
+++ b/src/hdy-stackable-box.c
@@ -3190,7 +3190,7 @@ hdy_stackable_box_switch_child (HdyStackableBox *self,
 }
 
 void
-hdy_stackable_box_begin_swipe (HdyStackableBox        *self,
+hdy_stackable_box_start_swipe (HdyStackableBox        *self,
                                HdyNavigationDirection  direction,
                                gboolean                direct)
 {
diff --git a/src/hdy-swipe-group.c b/src/hdy-swipe-group.c
index 0b05067f..d7c8ee44 100644
--- a/src/hdy-swipe-group.c
+++ b/src/hdy-swipe-group.c
@@ -118,7 +118,7 @@ switch_child_cb (HdySwipeGroup *self,
 }
 
 static void
-begin_swipe_cb (HdySwipeGroup          *self,
+start_swipe_cb (HdySwipeGroup          *self,
                 HdyNavigationDirection  direction,
                 HdySwipeable           *swipeable)
 {
@@ -131,7 +131,7 @@ begin_swipe_cb (HdySwipeGroup          *self,
 
   for (swipeables = self->swipeables; swipeables != NULL; swipeables = swipeables->next)
     if (swipeables->data != swipeable)
-      hdy_swipeable_begin_swipe (swipeables->data, direction, FALSE);
+      hdy_swipeable_start_swipe (swipeables->data, direction, FALSE);
 }
 
 static void
@@ -185,7 +185,7 @@ hdy_swipe_group_add_swipeable (HdySwipeGroup *self,
   g_return_if_fail (HDY_IS_SWIPEABLE (swipeable));
 
   g_signal_connect_swapped (swipeable, "switch-child", G_CALLBACK (switch_child_cb), self);
-  g_signal_connect_swapped (swipeable, "begin-swipe", G_CALLBACK (begin_swipe_cb), self);
+  g_signal_connect_swapped (swipeable, "start-swipe", G_CALLBACK (start_swipe_cb), self);
   g_signal_connect_swapped (swipeable, "update-swipe", G_CALLBACK (update_swipe_cb), self);
   g_signal_connect_swapped (swipeable, "end-swipe", G_CALLBACK (end_swipe_cb), self);
 
diff --git a/src/hdy-swipe-tracker.c b/src/hdy-swipe-tracker.c
index 9c880da6..8ce7c447 100644
--- a/src/hdy-swipe-tracker.c
+++ b/src/hdy-swipe-tracker.c
@@ -137,7 +137,7 @@ gesture_prepare (HdySwipeTracker        *self,
   if (self->state != HDY_SWIPE_TRACKER_STATE_NONE)
     return;
 
-  hdy_swipeable_begin_swipe (self->swipeable, direction, TRUE);
+  hdy_swipeable_start_swipe (self->swipeable, direction, TRUE);
 
   self->initial_progress = hdy_swipeable_get_progress (self->swipeable);
   self->progress = self->initial_progress;
diff --git a/src/hdy-swipeable-private.h b/src/hdy-swipeable-private.h
index 1fea7a9b..5e825ea4 100644
--- a/src/hdy-swipeable-private.h
+++ b/src/hdy-swipeable-private.h
@@ -14,7 +14,7 @@ G_BEGIN_DECLS
 void hdy_swipeable_switch_child (HdySwipeable *self,
                                  guint         index,
                                  gint64        duration);
-void hdy_swipeable_begin_swipe  (HdySwipeable           *self,
+void hdy_swipeable_start_swipe  (HdySwipeable           *self,
                                  HdyNavigationDirection  direction,
                                  gboolean                direct);
 void hdy_swipeable_update_swipe (HdySwipeable *self,
diff --git a/src/hdy-swipeable.c b/src/hdy-swipeable.c
index addd220a..b0e7c973 100644
--- a/src/hdy-swipeable.c
+++ b/src/hdy-swipeable.c
@@ -26,7 +26,7 @@ G_DEFINE_INTERFACE (HdySwipeable, hdy_swipeable, GTK_TYPE_WIDGET)
 
 enum {
   SIGNAL_SWITCH_CHILD,
-  SIGNAL_BEGIN_SWIPE,
+  SIGNAL_START_SWIPE,
   SIGNAL_UPDATE_SWIPE,
   SIGNAL_END_SWIPE,
   SIGNAL_LAST_SIGNAL,
@@ -60,7 +60,7 @@ hdy_swipeable_default_init (HdySwipeableInterface *iface)
                   G_TYPE_UINT, G_TYPE_INT64);
 
   /**
-   * HdySwipeable::begin-swipe:
+   * HdySwipeable::start-swipe:
    * @self: The #HdySwipeable instance
    * @direction: The direction of the swipe, can be 1 or -1
    *
@@ -71,8 +71,8 @@ hdy_swipeable_default_init (HdySwipeableInterface *iface)
    *
    * Since: 0.0.12
    */
-  signals[SIGNAL_BEGIN_SWIPE] =
-    g_signal_new ("begin-swipe",
+  signals[SIGNAL_START_SWIPE] =
+    g_signal_new ("start-swipe",
                   G_TYPE_FROM_INTERFACE (iface),
                   G_SIGNAL_RUN_FIRST,
                   0,
@@ -149,7 +149,7 @@ hdy_swipeable_switch_child (HdySwipeable *self,
 }
 
 /**
- * hdy_swipeable_begin_swipe:
+ * hdy_swipeable_start_swipe:
  * @self: a #HdySwipeable
  * @direction: The direction of the swipe
  * @direct: %TRUE if the swipe is directly triggered by a gesture,
@@ -168,7 +168,7 @@ hdy_swipeable_switch_child (HdySwipeable *self,
  * Since: 0.0.12
  */
 void
-hdy_swipeable_begin_swipe (HdySwipeable           *self,
+hdy_swipeable_start_swipe (HdySwipeable           *self,
                            HdyNavigationDirection  direction,
                            gboolean                direct)
 {
@@ -177,11 +177,11 @@ hdy_swipeable_begin_swipe (HdySwipeable           *self,
   g_return_if_fail (HDY_IS_SWIPEABLE (self));
 
   iface = HDY_SWIPEABLE_GET_IFACE (self);
-  g_return_if_fail (iface->begin_swipe != NULL);
+  g_return_if_fail (iface->start_swipe != NULL);
 
-  (* iface->begin_swipe) (self, direction, direct);
+  (* iface->start_swipe) (self, direction, direct);
 
-  g_signal_emit (self, signals[SIGNAL_BEGIN_SWIPE], 0, direction);
+  g_signal_emit (self, signals[SIGNAL_START_SWIPE], 0, direction);
 }
 
 /**
diff --git a/src/hdy-swipeable.h b/src/hdy-swipeable.h
index 1212919d..866b5bc9 100644
--- a/src/hdy-swipeable.h
+++ b/src/hdy-swipeable.h
@@ -23,7 +23,7 @@ G_DECLARE_INTERFACE (HdySwipeable, hdy_swipeable, HDY, SWIPEABLE, GtkWidget)
  * HdySwipeableInterface:
  * @parent: The parent interface.
  * @switch_child: Switches visible child.
  * @begin_swipe: Starts a swipe gesture.
  * @update_swipe: Updates swipe progress value.
  * @end_swipe: Ends a swipe gesture.
  * @get_distance: Gets the swipe distance.
@@ -43,7 +43,7 @@ struct _HdySwipeableInterface
   void (*switch_child) (HdySwipeable *self,
                         guint         index,
                         gint64        duration);
-  void (*begin_swipe)  (HdySwipeable           *self,
+  void (*start_swipe)  (HdySwipeable           *self,
                         HdyNavigationDirection  direction,
                         gboolean                direct);
   void (*update_swipe) (HdySwipeable *self,
@@ -23,7 +23,7 @@ G_DECLARE_INTERFACE (HdySwipeable, hdy_swipeable, HDY, SWIPEABLE, GtkWidget)
  * @parent: The parent interface.
  * @switch_child: Switches visible child.
- * @begin_swipe: Starts a swipe gesture.
+ * @start_swipe: Starts a swipe gesture.
  * @update_swipe: Updates swipe progress value.
  * @end_swipe: Ends a swipe gesture.


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]